[PATCH 2/4][SCTP]: Fix typo adaption - adaptation as per the latest API draft.

2006-12-20 Thread Sridhar Samudrala
[SCTP]: Fix typo adaption - adaptation as per the latest API draft.

Signed-off-by: Ivan Skytte Jorgensen [EMAIL PROTECTED]
Signed-off-by: Sridhar Samudrala [EMAIL PROTECTED]

---
commit 1a7a0d391fb51bb26892aec4c7d36e7d8ba09d57
tree bd77592b453c53ff1988b29fa8aad1e54f95a842
parent 28e1d37084a686f37cc6cc56f94d96954edf920e
author Ivan Skytte Jorgensen [EMAIL PROTECTED] Wed, 20 Dec 2006 14:53:39 -0800
committer Sridhar Samudrala [EMAIL PROTECTED] Wed, 20 Dec 2006 14:53:39 -0800

 include/linux/sctp.h|   10 +-
 include/net/sctp/structs.h  |8 
 include/net/sctp/ulpevent.h |2 +-
 include/net/sctp/user.h |   28 ++--
 net/sctp/sm_make_chunk.c|   24 
 net/sctp/sm_statefuns.c |   32 
 net/sctp/socket.c   |   34 +-
 net/sctp/ulpevent.c |   20 ++--
 8 files changed, 79 insertions(+), 79 deletions(-)

diff --git a/include/net/sctp/structs.h b/include/net/sctp/structs.h
index 8d7f26d..c9075d0 100644
--- a/include/net/sctp/structs.h
+++ b/include/net/sctp/structs.h
@@ -306,7 +306,7 @@ struct sctp_sock {
__u8 disable_fragments;
__u8 pd_mode;
__u8 v4mapped;
-   __u32 adaption_ind;
+   __u32 adaptation_ind;
 
/* Receive to here while partial delivery is in effect. */
struct sk_buff_head pd_lobby;
@@ -388,7 +388,7 @@ struct sctp_cookie {
/* Padding for future use */
__u8 padding;   
 
-   __u32 adaption_ind; 
+   __u32 adaptation_ind;
 

/* This is a shim for my peer's INIT packet, followed by
@@ -431,7 +431,7 @@ union sctp_params {
struct sctp_ipv4addr_param *v4;
struct sctp_ipv6addr_param *v6;
union sctp_addr_param *addr;
-   struct sctp_adaption_ind_param *aind;
+   struct sctp_adaptation_ind_param *aind;
 };
 
 /* RFC 2960.  Section 3.3.5 Heartbeat.
@@ -1483,7 +1483,7 @@ struct sctp_association {
__u8asconf_capable;  /* Does peer support ADDIP? */
__u8prsctp_capable;  /* Can peer do PR-SCTP? */
 
-   __u32   adaption_ind;/* Adaption Code point. */
+   __u32   adaptation_ind;  /* Adaptation Code point. */
 
/* This mask is used to disable sending the ASCONF chunk
 * with specified parameter to peer.
diff --git a/include/net/sctp/ulpevent.h b/include/net/sctp/ulpevent.h
index 1a4ddc1..2923e3d 100644
--- a/include/net/sctp/ulpevent.h
+++ b/include/net/sctp/ulpevent.h
@@ -120,7 +120,7 @@ struct sctp_ulpevent *sctp_ulpevent_make
const struct sctp_association *asoc,
__u32 indication, gfp_t gfp);
 
-struct sctp_ulpevent *sctp_ulpevent_make_adaption_indication(
+struct sctp_ulpevent *sctp_ulpevent_make_adaptation_indication(
const struct sctp_association *asoc, gfp_t gfp);
 
 struct sctp_ulpevent *sctp_ulpevent_make_rcvmsg(struct sctp_association *asoc,
diff --git a/include/net/sctp/user.h b/include/net/sctp/user.h
index 9e4a39f..4116b0d 100644
--- a/include/net/sctp/user.h
+++ b/include/net/sctp/user.h
@@ -75,8 +75,8 @@ #define SCTP_AUTOCLOSE SCTP_AUTOCLOSE
 #define SCTP_SET_PEER_PRIMARY_ADDR SCTP_SET_PEER_PRIMARY_ADDR
SCTP_PRIMARY_ADDR,
 #define SCTP_PRIMARY_ADDR SCTP_PRIMARY_ADDR
-   SCTP_ADAPTION_LAYER,  
-#define SCTP_ADAPTION_LAYER SCTP_ADAPTION_LAYER
+   SCTP_ADAPTATION_LAYER,
+#define SCTP_ADAPTATION_LAYER SCTP_ADAPTATION_LAYER
SCTP_DISABLE_FRAGMENTS,
 #define SCTP_DISABLE_FRAGMENTS SCTP_DISABLE_FRAGMENTS
SCTP_PEER_ADDR_PARAMS,
@@ -331,17 +331,17 @@ struct sctp_shutdown_event {
 };
 
 /*
- * 5.3.1.6 SCTP_ADAPTION_INDICATION
+ * 

Re: [PATCH 2/4][SCTP]: Fix typo adaption - adaptation as per the latest API draft.

2006-12-20 Thread David Miller
From: Sridhar Samudrala [EMAIL PROTECTED]
Date: Wed, 20 Dec 2006 16:00:50 -0800

 [SCTP]: Fix typo adaption - adaptation as per the latest API draft.
 
 Signed-off-by: Ivan Skytte Jorgensen [EMAIL PROTECTED]
 Signed-off-by: Sridhar Samudrala [EMAIL PROTECTED]

Applied, thanks Sridhar.
-
To unsubscribe from this list: send the line unsubscribe netdev in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
diff --git a/include/linux/sctp.h b/include/linux/sctp.h
index 35108fe..d4f8656 100644
--- a/include/linux/sctp.h
+++ b/include/linux/sctp.h
@@ -180,7 +180,7 @@ typedef enum {
SCTP_PARAM_ERR_CAUSE= __constant_htons(0xc003),
SCTP_PARAM_SET_PRIMARY  = __constant_htons(0xc004),
SCTP_PARAM_SUCCESS_REPORT   = __constant_htons(0xc005),
-   SCTP_PARAM_ADAPTION_LAYER_IND   = __constant_htons(0xc006),
+   SCTP_PARAM_ADAPTATION_LAYER_IND = __constant_htons(0xc006),
 
 } sctp_param_t; /* enum */
 
@@ -281,11 +281,11 @@ typedef struct sctp_ecn_capable_param {
sctp_paramhdr_t param_hdr;
 } __attribute__((packed)) sctp_ecn_capable_param_t;
 
-/* ADDIP Section 3.2.6 Adaption Layer Indication */
-typedef struct sctp_adaption_ind_param {
+/* ADDIP Section 3.2.6 Adaptation Layer Indication */
+typedef struct sctp_adaptation_ind_param {
struct sctp_paramhdr param_hdr;
-   __be32 adaption_ind;
-} __attribute__((packed)) sctp_adaption_ind_param_t;
+   __be32 adaptation_ind;
+} __attribute__((packed)) sctp_adaptation_ind_param_t;
 
 /* RFC 2960.  Section 3.3.3 Initiation Acknowledgement (INIT ACK) (2):
  *   The INIT ACK chunk is used to acknowledge the initiation of an SCTP